@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/ce_parser.c,v 1.5 2005/02/07 16:38:58 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/ce_parser.c,v 1.6 2005/12/19 15:46:57 richb Exp $
  *
  *  Copyright (C) 2004-2005 Sami Pietila
  *
@@ -24,8 +24,6 @@
 #include "extern.h"
 #include "calctool.h"
 
-#include "syntax_translation.h"
-
 /* TODO: This file is almost identical to lr-parser. */
 
 int 
@@ -42,7 +40,6 @@ ce_parse_(char *expression, int result[MP_SIZE], int flags)
     if (strlen(expression)) {
         parser_state.i = 0;
         parser_state.buff = gc_strdup(expression);
-        translate_tokens(&parser_state.buff);
         ret = ceparse();
         free(parser_state.buff);
     }
